@@ -1,21 +1,20 @@
 import os
 import matplotlib.pyplot as plt
 
-import dxf
-import utils
+import dxf 
+import utils 
 
 
 def import_dxf_example():
     dxf_filepath = os.path.join(os.getcwd(),'example_files','section_holes_complex.dxf')
     my_dxf = dxf.DxfImporter(dxf_filepath)
-    my_dxf.process()   
+    my_dxf.process(spline_delta = 0.5)   
     my_dxf.cleanup()
     
     polygons = my_dxf.polygons
     for p in polygons:
         x,y = p.exterior.xy
-   #     plt.plot(x,y)
-    
+ 
 
     new = utils.find_holes(polygons)
 
